# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from fastapi.encoders import jsonable_encoder

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _BeneficiaryRegistrationAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_beneficiary_registration_for_partner_applications(
        self, inline_object4: m.InlineObject4 = None
    ) -> Awaitable[m.InlineResponse2007]:
        """
        API for beneficiary registration from partner applications. This API returns a beneficiary reference id as a unique identifier of the registered user.
        """
        body = jsonable_encoder(inline_object4)

        return self.api_client.request(
            type_=m.InlineResponse2007, method="POST", url="/v2/registration/beneficiary/new", json=body
        )

    def _build_for_delete_beneficiary(self, inline_object5: m.InlineObject5 = None) -> Awaitable[None]:
        """
        API to delete a beneficiary by benefiary reference id.
        """
        body = jsonable_encoder(inline_object5)

        return self.api_client.request(type_=None, method="POST", url="/v2/registration/beneficiary/delete", json=body)


class AsyncBeneficiaryRegistrationAPIsApi(_BeneficiaryRegistrationAPIsApi):
    async def beneficiary_registration_for_partner_applications(
        self, inline_object4: m.InlineObject4 = None
    ) -> m.InlineResponse2007:
        """
        API for beneficiary registration from partner applications. This API returns a beneficiary reference id as a unique identifier of the registered user.
        """
        return await self._build_for_beneficiary_registration_for_partner_applications(inline_object4=inline_object4)

    async def delete_beneficiary(self, inline_object5: m.InlineObject5 = None) -> None:
        """
        API to delete a beneficiary by benefiary reference id.
        """
        return await self._build_for_delete_beneficiary(inline_object5=inline_object5)


class SyncBeneficiaryRegistrationAPIsApi(_BeneficiaryRegistrationAPIsApi):
    def beneficiary_registration_for_partner_applications(
        self, inline_object4: m.InlineObject4 = None
    ) -> m.InlineResponse2007:
        """
        API for beneficiary registration from partner applications. This API returns a beneficiary reference id as a unique identifier of the registered user.
        """
        coroutine = self._build_for_beneficiary_registration_for_partner_applications(inline_object4=inline_object4)
        return get_event_loop().run_until_complete(coroutine)

    def delete_beneficiary(self, inline_object5: m.InlineObject5 = None) -> None:
        """
        API to delete a beneficiary by benefiary reference id.
        """
        coroutine = self._build_for_delete_beneficiary(inline_object5=inline_object5)
        return get_event_loop().run_until_complete(coroutine)



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _MetadataAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_districts(self, state_id: str, accept_language: str = None) -> Awaitable[m.InlineResponse2003]:
        """
        API to get all the districts.
        """
        path_params = {"state_id": str(state_id)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.InlineResponse2003,
            method="GET",
            url="/v2/admin/location/districts/{state_id}",
            path_params=path_params,
            headers=headers,
        )

    def _build_for_find_by_lat_long(self, lat: float, long: float, accept_language: str = None) -> Awaitable[m.Any]:
        """
        API to get vaccination centers by latitude and longitude.
        """
        query_params = {"lat": str(lat), "long": str(long)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/centers/findByLatLong",
            params=query_params,
            headers=headers,
        )

    def _build_for_genders(self, accept_language: str = None) -> Awaitable[m.InlineResponse2006]:
        """
        API to get all gender details.
        """
        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.InlineResponse2006,
            method="GET",
            url="/v2/registration/beneficiary/genders",
            headers=headers,
        )

    def _build_for_id_types(self, accept_language: str = None) -> Awaitable[m.InlineResponse2005]:
        """
        API to get list of beneficiary Ids that can be used as proof of identity for registration.
        """
        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.InlineResponse2005,
            method="GET",
            url="/v2/registration/beneficiary/idTypes",
            headers=headers,
        )

    def _build_for_states(self, accept_language: str = None) -> Awaitable[m.InlineResponse2002]:
        """
        API to get all the states in India.
        """
        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.InlineResponse2002,
            method="GET",
            url="/v2/admin/location/states",
            headers=headers,
        )


class AsyncMetadataAPIsApi(_MetadataAPIsApi):
    async def districts(self, state_id: str, accept_language: str = None) -> m.InlineResponse2003:
        """
        API to get all the districts.
        """
        return await self._build_for_districts(state_id=state_id, accept_language=accept_language)

    async def find_by_lat_long(self, lat: float, long: float, accept_language: str = None) -> m.Any:
        """
        API to get vaccination centers by latitude and longitude.
        """
        return await self._build_for_find_by_lat_long(lat=lat, long=long, accept_language=accept_language)

    async def genders(self, accept_language: str = None) -> m.InlineResponse2006:
        """
        API to get all gender details.
        """
        return await self._build_for_genders(accept_language=accept_language)

    async def id_types(self, accept_language: str = None) -> m.InlineResponse2005:
        """
        API to get list of beneficiary Ids that can be used as proof of identity for registration.
        """
        return await self._build_for_id_types(accept_language=accept_language)

    async def states(self, accept_language: str = None) -> m.InlineResponse2002:
        """
        API to get all the states in India.
        """
        return await self._build_for_states(accept_language=accept_language)


class SyncMetadataAPIsApi(_MetadataAPIsApi):
    def districts(self, state_id: str, accept_language: str = None) -> m.InlineResponse2003:
        """
        API to get all the districts.
        """
        coroutine = self._build_for_districts(state_id=state_id, accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)

    def find_by_lat_long(self, lat: float, long: float, accept_language: str = None) -> m.Any:
        """
        API to get vaccination centers by latitude and longitude.
        """
        coroutine = self._build_for_find_by_lat_long(lat=lat, long=long, accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)

    def genders(self, accept_language: str = None) -> m.InlineResponse2006:
        """
        API to get all gender details.
        """
        coroutine = self._build_for_genders(accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)

    def id_types(self, accept_language: str = None) -> m.InlineResponse2005:
        """
        API to get list of beneficiary Ids that can be used as proof of identity for registration.
        """
        coroutine = self._build_for_id_types(accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)

    def states(self, accept_language: str = None) -> m.InlineResponse2002:
        """
        API to get all the states in India.
        """
        coroutine = self._build_for_states(accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from fastapi.encoders import jsonable_encoder

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _VaccinationAppointmentAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_beneficiaries(
        self,
    ) -> Awaitable[m.Any]:
        """
        API to get the list of benefiaries linked to the logged in/authenticated user’s mobile number. This list can be useful to schedule one appointment for an entire family.
        """
        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/beneficiaries",
        )

    def _build_for_calendar_by_district(
        self, district_id: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        query_params = {
            "district_id": str(district_id),
            "date": str(date),
        }
        if vaccine is not None:
            query_params["vaccine"] = str(vaccine)

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/calendarByDistrict",
            params=query_params,
            headers=headers,
        )

    def _build_for_calendar_by_pin(
        self, pincode: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        query_params = {
            "pincode": str(pincode),
            "date": str(date),
        }
        if vaccine is not None:
            query_params["vaccine"] = str(vaccine)

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/calendarByPin",
            params=query_params,
            headers=headers,
        )

    def _build_for_cancel_appointment(self, inline_object8: m.InlineObject8 = None) -> Awaitable[None]:
        """
        API to remove an individual from an appointment.
        """
        body = jsonable_encoder(inline_object8)

        return self.api_client.request(type_=None, method="POST", url="/v2/appointment/cancel", json=body)

    def _build_for_find_by_district(
        self, district_id: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions on a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        query_params = {
            "district_id": str(district_id),
            "date": str(date),
        }
        if vaccine is not None:
            query_params["vaccine"] = str(vaccine)

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/findByDistrict",
            params=query_params,
            headers=headers,
        )

    def _build_for_find_by_pin(
        self, pincode: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions on a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        query_params = {
            "pincode": str(pincode),
            "date": str(date),
        }
        if vaccine is not None:
            query_params["vaccine"] = str(vaccine)

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/findByPin",
            params=query_params,
            headers=headers,
        )

    def _build_for_reschedule_appointment(self, inline_object7: m.InlineObject7 = None) -> Awaitable[None]:
        """
        API to reschedule an appointment for vaccination.
        """
        body = jsonable_encoder(inline_object7)

        return self.api_client.request(type_=None, method="POST", url="/v2/appointment/reschedule", json=body)

    def _build_for_schedule(self, inline_object6: m.InlineObject6 = None) -> Awaitable[m.Any]:
        """
        API to schedule an appointment for vaccination. An appointment can be scheduled for a selected center, on a selected date and for a selected session. An appointment can be scheduled for multiple beneficiaries provided their registered mobile number is same as the registered mobile number of the logged in or authenticated beneficiary.
        """
        body = jsonable_encoder(inline_object6)

        return self.api_client.request(type_=m.Any, method="POST", url="/v2/appointment/schedule", json=body)


class AsyncVaccinationAppointmentAPIsApi(_VaccinationAppointmentAPIsApi):
    async def beneficiaries(
        self,
    ) -> m.Any:
        """
        API to get the list of benefiaries linked to the logged in/authenticated user’s mobile number. This list can be useful to schedule one appointment for an entire family.
        """
        return await self._build_for_beneficiaries()

    async def calendar_by_district(
        self, district_id: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        return await self._build_for_calendar_by_district(
            district_id=district_id, date=date, accept_language=accept_language, vaccine=vaccine
        )

    async def calendar_by_pin(self, pincode: str, date: str, accept_language: str = None, vaccine: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        return await self._build_for_calendar_by_pin(
            pincode=pincode, date=date, accept_language=accept_language, vaccine=vaccine
        )

    async def cancel_appointment(self, inline_object8: m.InlineObject8 = None) -> None:
        """
        API to remove an individual from an appointment.
        """
        return await self._build_for_cancel_appointment(inline_object8=inline_object8)

    async def find_by_district(
        self, district_id: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        return await self._build_for_find_by_district(
            district_id=district_id, date=date, accept_language=accept_language, vaccine=vaccine
        )

    async def find_by_pin(self, pincode: str, date: str, accept_language: str = None, vaccine: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        return await self._build_for_find_by_pin(
            pincode=pincode, date=date, accept_language=accept_language, vaccine=vaccine
        )

    async def reschedule_appointment(self, inline_object7: m.InlineObject7 = None) -> None:
        """
        API to reschedule an appointment for vaccination.
        """
        return await self._build_for_reschedule_appointment(inline_object7=inline_object7)

    async def schedule(self, inline_object6: m.InlineObject6 = None) -> m.Any:
        """
        API to schedule an appointment for vaccination. An appointment can be scheduled for a selected center, on a selected date and for a selected session. An appointment can be scheduled for multiple beneficiaries provided their registered mobile number is same as the registered mobile number of the logged in or authenticated beneficiary.
        """
        return await self._build_for_schedule(inline_object6=inline_object6)


class SyncVaccinationAppointmentAPIsApi(_VaccinationAppointmentAPIsApi):
    def beneficiaries(
        self,
    ) -> m.Any:
        """
        API to get the list of benefiaries linked to the logged in/authenticated user’s mobile number. This list can be useful to schedule one appointment for an entire family.
        """
        coroutine = self._build_for_beneficiaries()
        return get_event_loop().run_until_complete(coroutine)

    def calendar_by_district(
        self, district_id: str, date: str, accept_language: str = None, vaccine: str = None
    ) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        coroutine = self._build_for_calendar_by_district(
            district_id=district_id, date=date, accept_language=accept_language, vaccine=vaccine
        )
        return get_event_loop().run_until_complete(coroutine)

    def calendar_by_pin(self, pincode: str, date: str, accept_language: str = None, vaccine: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        coroutine = self._build_for_calendar_by_pin(
            pincode=pincode, date=date, accept_language=accept_language, vaccine=vaccine
        )
        return get_event_loop().run_until_complete(coroutine)

    def cancel_appointment(self, inline_object8: m.InlineObject8 = None) -> None:
        """
        API to remove an individual from an appointment.
        """
        coroutine = self._build_for_cancel_appointment(inline_object8=inline_object8)
        return get_event_loop().run_until_complete(coroutine)

    def find_by_district(self, district_id: str, date: str, accept_language: str = None, vaccine: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given district. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        coroutine = self._build_for_find_by_district(
            district_id=district_id, date=date, accept_language=accept_language, vaccine=vaccine
        )
        return get_event_loop().run_until_complete(coroutine)

    def find_by_pin(self, pincode: str, date: str, accept_language: str = None, vaccine: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given pin. An optional parameter <i>vaccine</i> can also used to get the sessions for a specific vaccine. This paramters is used to to get the sessions for dose 2 appointment.
        """
        coroutine = self._build_for_find_by_pin(
            pincode=pincode, date=date, accept_language=accept_language, vaccine=vaccine
        )
        return get_event_loop().run_until_complete(coroutine)

    def reschedule_appointment(self, inline_object7: m.InlineObject7 = None) -> None:
        """
        API to reschedule an appointment for vaccination.
        """
        coroutine = self._build_for_reschedule_appointment(inline_object7=inline_object7)
        return get_event_loop().run_until_complete(coroutine)

    def schedule(self, inline_object6: m.InlineObject6 = None) -> m.Any:
        """
        API to schedule an appointment for vaccination. An appointment can be scheduled for a selected center, on a selected date and for a selected session. An appointment can be scheduled for multiple beneficiaries provided their registered mobile number is same as the registered mobile number of the logged in or authenticated beneficiary.
        """
        coroutine = self._build_for_schedule(inline_object6=inline_object6)
        return get_event_loop().run_until_complete(coroutine)



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from fastapi.encoders import jsonable_encoder

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _UserAuthenticationAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_public_confirm_otp(self, inline_object1: m.InlineObject1 = None) -> Awaitable[m.InlineResponse2001]:
        """
        API to confirm the OTP for authentication.
        """
        body = jsonable_encoder(inline_object1)

        return self.api_client.request(
            type_=m.InlineResponse2001, method="POST", url="/v2/auth/public/confirmOTP", json=body
        )

    def _build_for_public_generate_otp(self, inline_object: m.InlineObject = None) -> Awaitable[m.InlineResponse200]:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        body = jsonable_encoder(inline_object)

        return self.api_client.request(
            type_=m.InlineResponse200, method="POST", url="/v2/auth/public/generateOTP", json=body
        )


class AsyncUserAuthenticationAPIsApi(_UserAuthenticationAPIsApi):
    async def public_confirm_otp(self, inline_object1: m.InlineObject1 = None) -> m.InlineResponse2001:
        """
        API to confirm the OTP for authentication.
        """
        return await self._build_for_public_confirm_otp(inline_object1=inline_object1)

    async def public_generate_otp(self, inline_object: m.InlineObject = None) -> m.InlineResponse200:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        return await self._build_for_public_generate_otp(inline_object=inline_object)


class SyncUserAuthenticationAPIsApi(_UserAuthenticationAPIsApi):
    def public_confirm_otp(self, inline_object1: m.InlineObject1 = None) -> m.InlineResponse2001:
        """
        API to confirm the OTP for authentication.
        """
        coroutine = self._build_for_public_confirm_otp(inline_object1=inline_object1)
        return get_event_loop().run_until_complete(coroutine)

    def public_generate_otp(self, inline_object: m.InlineObject = None) -> m.InlineResponse200:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        coroutine = self._build_for_public_generate_otp(inline_object=inline_object)
        return get_event_loop().run_until_complete(coroutine)



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _AppointmentAvailabilityAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_public_calendar_by_district(
        self, district_id: str, date: str, accept_language: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district.
        """
        query_params = {"district_id": str(district_id), "date": str(date)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/public/calendarByDistrict",
            params=query_params,
            headers=headers,
        )

    def _build_for_public_calendar_by_pin(
        self, pincode: str, date: str, accept_language: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin.
        """
        query_params = {"pincode": str(pincode), "date": str(date)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/public/calendarByPin",
            params=query_params,
            headers=headers,
        )

    def _build_for_public_find_by_district(
        self, district_id: str, date: str, accept_language: str = None
    ) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions on a specific date in a given district.
        """
        query_params = {"district_id": str(district_id), "date": str(date)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/public/findByDistrict",
            params=query_params,
            headers=headers,
        )

    def _build_for_public_find_by_pin(self, pincode: str, date: str, accept_language: str = None) -> Awaitable[m.Any]:
        """
        API to get planned vaccination sessions on a specific date in a given pin.
        """
        query_params = {"pincode": str(pincode), "date": str(date)}

        headers = {}
        if accept_language is not None:
            headers["Accept-Language"] = str(accept_language)

        return self.api_client.request(
            type_=m.Any,
            method="GET",
            url="/v2/appointment/sessions/public/findByPin",
            params=query_params,
            headers=headers,
        )


class AsyncAppointmentAvailabilityAPIsApi(_AppointmentAvailabilityAPIsApi):
    async def public_calendar_by_district(self, district_id: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district.
        """
        return await self._build_for_public_calendar_by_district(
            district_id=district_id, date=date, accept_language=accept_language
        )

    async def public_calendar_by_pin(self, pincode: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin.
        """
        return await self._build_for_public_calendar_by_pin(pincode=pincode, date=date, accept_language=accept_language)

    async def public_find_by_district(self, district_id: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given district.
        """
        return await self._build_for_public_find_by_district(
            district_id=district_id, date=date, accept_language=accept_language
        )

    async def public_find_by_pin(self, pincode: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given pin.
        """
        return await self._build_for_public_find_by_pin(pincode=pincode, date=date, accept_language=accept_language)


class SyncAppointmentAvailabilityAPIsApi(_AppointmentAvailabilityAPIsApi):
    def public_calendar_by_district(self, district_id: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given district.
        """
        coroutine = self._build_for_public_calendar_by_district(
            district_id=district_id, date=date, accept_language=accept_language
        )
        return get_event_loop().run_until_complete(coroutine)

    def public_calendar_by_pin(self, pincode: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions for 7 days from a specific date in a given pin.
        """
        coroutine = self._build_for_public_calendar_by_pin(pincode=pincode, date=date, accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)

    def public_find_by_district(self, district_id: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given district.
        """
        coroutine = self._build_for_public_find_by_district(
            district_id=district_id, date=date, accept_language=accept_language
        )
        return get_event_loop().run_until_complete(coroutine)

    def public_find_by_pin(self, pincode: str, date: str, accept_language: str = None) -> m.Any:
        """
        API to get planned vaccination sessions on a specific date in a given pin.
        """
        coroutine = self._build_for_public_find_by_pin(pincode=pincode, date=date, accept_language=accept_language)
        return get_event_loop().run_until_complete(coroutine)



"""
Attempting to follow the "password" flow as described in RFC 6749: https://tools.ietf.org/html/rfc6749
"""
from asyncio import get_event_loop
from contextlib import suppress
from enum import Enum
from typing import Any, Dict, List, Optional, Type, TypeVar, Union

from fastapi.openapi.models import OAuthFlowPassword
from httpx import AsyncClient, Response
from pydantic import BaseModel, ValidationError
from typing_extensions import Literal

from cowin_api.exceptions import UnexpectedResponse

TokenRequestT = TypeVar("TokenRequestT", bound="BaseTokenRequest")
HTTP_200_OK = 200
HTTP_400_BAD_REQUEST = 400
HTTP_401_UNAUTHORIZED = 401


class BaseTokenRequest(BaseModel):
    scope: Optional[str]

    def request_dict(self) -> Dict[str, str]:
        request_dict = self.dict()
        if request_dict["scope"] is None:
            del request_dict["scope"]
        return request_dict

    @classmethod
    def from_scopes(cls: Type[TokenRequestT], *, scopes: Optional[List[str]], **kwargs: Any) -> TokenRequestT:
        scope = " ".join(scopes) if scopes is not None else None
        return cls(scope=scope, **kwargs)


class AccessTokenRequest(BaseTokenRequest):
    """
    Specific to the OAuth2.0 "password" flow
    """

    grant_type: Literal["password"] = "password"
    username: str
    password: str
    scope: Optional[str]


class RefreshTokenRequest(BaseTokenRequest):
    grant_type: Literal["refresh_token"] = "refresh_token"
    refresh_token: str
    scope: Optional[str]


class TokenSuccessResponse(BaseModel):
    access_token: str
    token_type: str
    expires_in: Optional[int]
    refresh_token: Optional[str]
    scope: Optional[str]


class TokenErrorType(Enum):
    invalid_request = "invalid_request"
    invalid_client = "invalid_client"
    invalid_grant = "invalid_grant"
    unauthorized_client = "unauthorized_client"
    unsupported_grant_type = "unsupported_grant_type"
    invalid_scope = "invalid_scope"


class TokenErrorResponse(BaseModel):
    error: Union[TokenErrorType, str]
    error_description: Optional[str]
    error_uri: Optional[str]


TokenResponse = Union[TokenSuccessResponse, TokenErrorResponse]


def parse_token_response(response: Response) -> TokenResponse:
    with suppress(ValidationError):
        if response.status_code == HTTP_200_OK:
            return TokenSuccessResponse.parse_raw(response.text)
        if response.status_code in (HTTP_400_BAD_REQUEST, HTTP_401_UNAUTHORIZED):
            return TokenErrorResponse.parse_raw(response.text)
    raise UnexpectedResponse.for_response(response)


class PasswordFlowClient:
    def __init__(self, flow: OAuthFlowPassword) -> None:
        self.flow = flow
        self._async_client = AsyncClient()

    async def request_access_token(self, access_token_request: AccessTokenRequest) -> TokenResponse:
        response = await self._async_client.post(self.flow.tokenUrl, data=access_token_request.request_dict())
        return parse_token_response(response)

    async def request_refresh_token(self, refresh_token_request: RefreshTokenRequest) -> TokenResponse:
        refresh_url = self.flow.refreshUrl or self.flow.tokenUrl
        response = await self._async_client.post(refresh_url, data=refresh_token_request.request_dict())
        return parse_token_response(response)

    def request_access_token_sync(self, access_token_request: AccessTokenRequest) -> TokenResponse:
        return get_event_loop().run_until_complete(self.request_access_token(access_token_request))

    def request_refresh_token_sync(self, refresh_token_request: RefreshTokenRequest) -> TokenResponse:
        return get_event_loop().run_until_complete(self.request_refresh_token(refresh_token_request))



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable
from uuid import UUID

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _CertificateAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_download(self, beneficiary_reference_id: str) -> Awaitable[m.IO]:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id.
        """
        query_params = {"beneficiary_reference_id": str(beneficiary_reference_id)}

        return self.api_client.request(
            type_=m.IO,
            method="GET",
            url="/v2/registration/certificate/download",
            params=query_params,
        )

    def _build_for_download_appointment_slip(self, appointment_id: UUID) -> Awaitable[m.IO]:
        """
        API to download vaccination appointment slip in PDF format by appointment id.
        """
        query_params = {"appointment_id": str(appointment_id)}

        return self.api_client.request(
            type_=m.IO,
            method="GET",
            url="/v2/appointment/appointmentslip/download",
            params=query_params,
        )

    def _build_for_public_download(self, beneficiary_reference_id: str) -> Awaitable[m.IO]:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id. This API requires a <i>Bearer</i> token acquired with user mobile OTP validation as defined in User Authentication APIs.
        """
        query_params = {"beneficiary_reference_id": str(beneficiary_reference_id)}

        return self.api_client.request(
            type_=m.IO,
            method="GET",
            url="/v2/registration/certificate/public/download",
            params=query_params,
        )


class AsyncCertificateAPIsApi(_CertificateAPIsApi):
    async def download(self, beneficiary_reference_id: str) -> m.IO:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id.
        """
        return await self._build_for_download(beneficiary_reference_id=beneficiary_reference_id)

    async def download_appointment_slip(self, appointment_id: UUID) -> m.IO:
        """
        API to download vaccination appointment slip in PDF format by appointment id.
        """
        return await self._build_for_download_appointment_slip(appointment_id=appointment_id)

    async def public_download(self, beneficiary_reference_id: str) -> m.IO:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id. This API requires a <i>Bearer</i> token acquired with user mobile OTP validation as defined in User Authentication APIs.
        """
        return await self._build_for_public_download(beneficiary_reference_id=beneficiary_reference_id)


class SyncCertificateAPIsApi(_CertificateAPIsApi):
    def download(self, beneficiary_reference_id: str) -> m.IO:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id.
        """
        coroutine = self._build_for_download(beneficiary_reference_id=beneficiary_reference_id)
        return get_event_loop().run_until_complete(coroutine)

    def download_appointment_slip(self, appointment_id: UUID) -> m.IO:
        """
        API to download vaccination appointment slip in PDF format by appointment id.
        """
        coroutine = self._build_for_download_appointment_slip(appointment_id=appointment_id)
        return get_event_loop().run_until_complete(coroutine)

    def public_download(self, beneficiary_reference_id: str) -> m.IO:
        """
        API to download vaccination certificate in PDF format by beneficiary reference id. This API requires a <i>Bearer</i> token acquired with user mobile OTP validation as defined in User Authentication APIs.
        """
        coroutine = self._build_for_public_download(beneficiary_reference_id=beneficiary_reference_id)
        return get_event_loop().run_until_complete(coroutine)



import inspect

from pydantic import BaseModel

from cowin_api import models
from cowin_api.api_client import ApiClient, AsyncApis, SyncApis  # noqa F401

for model in inspect.getmembers(models, inspect.isclass):
    if model[1].__module__ == "cowin_api.models":
        model_class = model[1]
        if isinstance(model_class, BaseModel):
            model_class.update_forward_refs()



from contextlib import suppress
from datetime import datetime, timedelta
from typing import Optional

from fastapi.openapi.models import OAuthFlowPassword
from httpx import Request, Response
from pydantic import BaseModel

from cowin_api.api_client import Send
from cowin_api.exceptions import UnexpectedResponse
from cowin_api.password_flow_client import (
    AccessTokenRequest,
    PasswordFlowClient,
    RefreshTokenRequest,
    TokenSuccessResponse,
)

HTTP_401_UNAUTHORIZED = 401


class AuthState(BaseModel):
    username: Optional[str]
    password: Optional[str]
    access_token: Optional[str]
    refresh_token: Optional[str]
    expires_at: Optional[datetime]  # should be UTC
    scope: Optional[str]

    def get_login_request(self) -> Optional[AccessTokenRequest]:
        if self.username is None or self.password is None:
            return None
        return AccessTokenRequest(username=self.username, password=self.password, scope=self.scope)

    def get_refresh_request(self) -> Optional[RefreshTokenRequest]:
        if self.refresh_token is None:
            return None
        return RefreshTokenRequest(refresh_token=self.refresh_token, scope=self.scope)

    def is_expired(self) -> bool:
        if self.expires_at is None:
            return False
        return self.expires_at < datetime.utcnow() + timedelta(seconds=30)

    def update(self, token_success_response: TokenSuccessResponse) -> None:
        self.access_token = token_success_response.access_token
        self.refresh_token = token_success_response.refresh_token
        self.scope = token_success_response.scope
        if token_success_response.expires_in is not None:
            self.expires_at = datetime.utcnow() + timedelta(seconds=token_success_response.expires_in)


class AuthMiddleware:
    def __init__(self, auth_state: AuthState, flow: OAuthFlowPassword) -> None:
        self.auth_state = auth_state
        self.flow_client = PasswordFlowClient(flow)

    @staticmethod
    def set_access_header(token: str, request: Request, *, replace: bool) -> None:
        key = "authorization"
        value = f"bearer {token}"
        if replace:
            request.headers[key] = value
        else:
            request.headers.setdefault(key, value)

    async def login(self) -> Optional[TokenSuccessResponse]:
        access_token_request = self.auth_state.get_login_request()
        if access_token_request is None:
            return None
        with suppress(UnexpectedResponse):
            token_response = await self.flow_client.request_access_token(access_token_request)
            if isinstance(token_response, TokenSuccessResponse):
                self.update_auth_state(token_response)
                return token_response
        return None

    async def refresh(self) -> Optional[TokenSuccessResponse]:
        refresh_token_request = self.auth_state.get_refresh_request()
        if refresh_token_request is None:
            return None
        with suppress(UnexpectedResponse):
            token_response = await self.flow_client.request_refresh_token(refresh_token_request)
            if isinstance(token_response, TokenSuccessResponse):
                self.update_auth_state(token_response)
                return token_response
        return None

    async def __call__(self, request: Request, call_next: Send) -> Response:
        if self.auth_state.is_expired():
            await self.refresh()
        access_token = self.auth_state.access_token
        if access_token is not None:
            self.set_access_header(access_token, request, replace=False)

        response = await call_next(request)

        if response.status_code != HTTP_401_UNAUTHORIZED:
            return response
        tokens = await self.refresh()
        if tokens is None:
            tokens = await self.login()
        if tokens:
            self.set_access_header(tokens.access_token, request, replace=True)
            return await call_next(request)  # note: won't work with streaming input
        return response

    def update_auth_state(self, tokens: TokenSuccessResponse) -> None:
        """
        Override this function if you want a hook for caching the access/refresh tokens
        """
        self.auth_state.update(tokens)



# coding: utf-8

"""
    Co-WIN Protected APIs

    Co-WIN APIs to register for vaccination, to book a vaccination appointment from partner applications. These APIs have restricted access. Please contact Ministry of Health and Family Welfare, Government of India to get access to these APIs. <i>[Updated on 25 Apr 2021]</i>  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "cowin-api"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["pydantic", "httpx", "fastapi", "typing_extensions"]

setup(
    name=NAME,
    version=VERSION,
    description="Co-WIN Protected APIs",
    author_email="",
    url="",
    keywords=["Swagger", "Co-WIN Protected APIs"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    package_data={
        "cowin_api": ["py.typed"],
    },
    long_description="""\
    Co-WIN APIs to register for vaccination, to book a vaccination appointment from partner applications. These APIs have restricted access. Please contact Ministry of Health and Family Welfare, Government of India to get access to these APIs. &lt;i&gt;[Updated on 25 Apr 2021]&lt;/i&gt;  # noqa: E501
    """
)



# flake8: noqa E501
from asyncio import get_event_loop
from typing import TYPE_CHECKING, Awaitable

from fastapi.encoders import jsonable_encoder

from cowin_api import models as m

if TYPE_CHECKING:
    from cowin_api.api_client import ApiClient


class _AuthenticationAPIsApi:
    def __init__(self, api_client: "ApiClient"):
        self.api_client = api_client

    def _build_for_confirm_otp(self, inline_object3: m.InlineObject3 = None) -> Awaitable[m.InlineResponse2004]:
        """
        API to confirm the OTP for authentication.
        """
        body = jsonable_encoder(inline_object3)

        return self.api_client.request(type_=m.InlineResponse2004, method="POST", url="/v2/auth/confirmOTP", json=body)

    def _build_for_generate_otp(self, inline_object2: m.InlineObject2 = None) -> Awaitable[m.InlineResponse200]:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        body = jsonable_encoder(inline_object2)

        return self.api_client.request(type_=m.InlineResponse200, method="POST", url="/v2/auth/generateOTP", json=body)


class AsyncAuthenticationAPIsApi(_AuthenticationAPIsApi):
    async def confirm_otp(self, inline_object3: m.InlineObject3 = None) -> m.InlineResponse2004:
        """
        API to confirm the OTP for authentication.
        """
        return await self._build_for_confirm_otp(inline_object3=inline_object3)

    async def generate_otp(self, inline_object2: m.InlineObject2 = None) -> m.InlineResponse200:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        return await self._build_for_generate_otp(inline_object2=inline_object2)


class SyncAuthenticationAPIsApi(_AuthenticationAPIsApi):
    def confirm_otp(self, inline_object3: m.InlineObject3 = None) -> m.InlineResponse2004:
        """
        API to confirm the OTP for authentication.
        """
        coroutine = self._build_for_confirm_otp(inline_object3=inline_object3)
        return get_event_loop().run_until_complete(coroutine)

    def generate_otp(self, inline_object2: m.InlineObject2 = None) -> m.InlineResponse200:
        """
        Initiate beneficiary authentication using mobile and OTP
        """
        coroutine = self._build_for_generate_otp(inline_object2=inline_object2)
        return get_event_loop().run_until_complete(coroutine)



from typing import Any  # noqa
from typing import List, Optional
from uuid import UUID

from pydantic import BaseModel, Field
from typing_extensions import Literal


class AppointmentResponseSchema(BaseModel):
    center_id: "float" = Field(..., alias="center_id")
    name: "str" = Field(..., alias="name")
    name_l: "Optional[str]" = Field(None, alias="name_l")
    state_name: "str" = Field(..., alias="state_name")
    state_name_l: "Optional[str]" = Field(None, alias="state_name_l")
    district_name: "str" = Field(..., alias="district_name")
    district_name_l: "Optional[str]" = Field(None, alias="district_name_l")
    block_name: "str" = Field(..., alias="block_name")
    block_name_l: "Optional[str]" = Field(None, alias="block_name_l")
    pincode: "str" = Field(..., alias="pincode")
    lat: "Optional[float]" = Field(None, alias="lat")
    long: "Optional[float]" = Field(None, alias="long")
    _from: "str" = Field(..., alias="from")
    to: "str" = Field(..., alias="to")
    fee_type: "Literal['Free', 'Paid']" = Field(..., alias="fee_type")
    dose: "float" = Field(..., alias="dose")
    appointment_id: "UUID" = Field(..., alias="appointment_id")
    session_id: "UUID" = Field(..., alias="session_id")
    date: "str" = Field(..., alias="date")
    slot: "str" = Field(..., alias="slot")


class AppointmentResponseSchemaAllOf(BaseModel):
    dose: "float" = Field(..., alias="dose")
    appointment_id: "UUID" = Field(..., alias="appointment_id")
    session_id: "UUID" = Field(..., alias="session_id")
    date: "str" = Field(..., alias="date")
    slot: "str" = Field(..., alias="slot")


class BenefeiciaryResponseSchema(BaseModel):
    beneficiary_reference_id: "str" = Field(..., alias="beneficiary_reference_id")
    name: "str" = Field(..., alias="name")
    birth_year: "str" = Field(..., alias="birth_year")
    gender: "str" = Field(..., alias="gender")
    mobile_number: "str" = Field(..., alias="mobile_number")
    photo_id_type: "str" = Field(..., alias="photo_id_type")
    photo_id_number: "str" = Field(..., alias="photo_id_number")
    comorbidity_ind: "Literal['Y', 'N']" = Field(..., alias="comorbidity_ind")
    vaccination_status: "Literal['Not Vaccinated', 'Partially Vaccinated', 'Vaccinated']" = Field(
        None, alias="vaccination_status"
    )
    vaccine: "Literal['COVISHIELD', 'COVAXIN']" = Field(None, alias="vaccine")
    dose1_date: "Optional[str]" = Field(None, alias="dose1_date")
    dose2_date: "Optional[str]" = Field(None, alias="dose2_date")
    appointments: "Optional[List[AppointmentResponseSchema]]" = Field(None, alias="appointments")


class CenterResponseSchema(BaseModel):
    center_id: "float" = Field(..., alias="center_id")
    name: "str" = Field(..., alias="name")
    name_l: "Optional[str]" = Field(None, alias="name_l")
    state_name: "str" = Field(..., alias="state_name")
    state_name_l: "Optional[str]" = Field(None, alias="state_name_l")
    district_name: "str" = Field(..., alias="district_name")
    district_name_l: "Optional[str]" = Field(None, alias="district_name_l")
    block_name: "str" = Field(..., alias="block_name")
    block_name_l: "Optional[str]" = Field(None, alias="block_name_l")
    pincode: "str" = Field(..., alias="pincode")
    lat: "Optional[float]" = Field(None, alias="lat")
    long: "Optional[float]" = Field(None, alias="long")
    _from: "str" = Field(..., alias="from")
    to: "str" = Field(..., alias="to")
    fee_type: "Literal['Free', 'Paid']" = Field(..., alias="fee_type")


class InlineObject(BaseModel):
    mobile: "Optional[str]" = Field(None, alias="mobile")


class InlineObject1(BaseModel):
    otp: "Optional[str]" = Field(None, alias="otp")
    txn_id: "Optional[UUID]" = Field(None, alias="txnId")


class InlineObject2(BaseModel):
    mobile: "Optional[str]" = Field(None, alias="mobile")


class InlineObject3(BaseModel):
    otp: "Optional[str]" = Field(None, alias="otp")
    txn_id: "Optional[UUID]" = Field(None, alias="txnId")


class InlineObject4(BaseModel):
    name: "str" = Field(..., alias="name")
    birth_year: "str" = Field(..., alias="birth_year")
    gender_id: "Optional[float]" = Field(None, alias="gender_id")
    photo_id_type: "float" = Field(..., alias="photo_id_type")
    photo_id_number: "str" = Field(..., alias="photo_id_number")
    comorbidity_ind: "Literal['Y', 'N']" = Field(None, alias="comorbidity_ind")
    consent_version: "str" = Field(..., alias="consent_version")


class InlineObject5(BaseModel):
    beneficiary_reference_id: "Optional[str]" = Field(None, alias="beneficiary_reference_id")


class InlineObject6(BaseModel):
    dose: "Optional[float]" = Field(None, alias="dose")
    session_id: "UUID" = Field(..., alias="session_id")
    slot: "str" = Field(..., alias="slot")
    beneficiaries: "List[str]" = Field(..., alias="beneficiaries")


class InlineObject7(BaseModel):
    appointment_id: "UUID" = Field(..., alias="appointment_id")
    session_id: "UUID" = Field(..., alias="session_id")
    slot: "str" = Field(..., alias="slot")


class InlineObject8(BaseModel):
    appointment_id: "UUID" = Field(..., alias="appointment_id")
    beneficiaries_to_cancel: "Optional[List[str]]" = Field(None, alias="beneficiariesToCancel")


class InlineResponse200(BaseModel):
    txn_id: "Optional[UUID]" = Field(None, alias="txnId")


class InlineResponse2001(BaseModel):
    token: "Optional[str]" = Field(None, alias="token")


class InlineResponse2002(BaseModel):
    states: "Optional[List[InlineResponse2002States]]" = Field(None, alias="states")
    ttl: "Optional[float]" = Field(None, alias="ttl")


class InlineResponse2002States(BaseModel):
    state_id: "float" = Field(..., alias="state_id")
    state_name: "str" = Field(..., alias="state_name")
    state_name_l: "Optional[str]" = Field(None, alias="state_name_l")


class InlineResponse2003(BaseModel):
    districts: "Optional[List[InlineResponse2003Districts]]" = Field(None, alias="districts")
    ttl: "Optional[float]" = Field(None, alias="ttl")


class InlineResponse2003Districts(BaseModel):
    state_id: "Optional[float]" = Field(None, alias="state_id")
    district_id: "float" = Field(..., alias="district_id")
    district_name: "str" = Field(..., alias="district_name")
    district_name_l: "Optional[str]" = Field(None, alias="district_name_l")


class InlineResponse2004(BaseModel):
    token: "Optional[str]" = Field(None, alias="token")
    is_new_account: "Literal['Y', 'N']" = Field(None, alias="isNewAccount")


class InlineResponse2005(BaseModel):
    types: "Optional[List[InlineResponse2005Types]]" = Field(None, alias="types")
    ttl: "Optional[float]" = Field(None, alias="ttl")


class InlineResponse2005Types(BaseModel):
    type: "str" = Field(..., alias="type")
    type_l: "Optional[str]" = Field(None, alias="type_l")
    id: "float" = Field(..., alias="id")


class InlineResponse2006(BaseModel):
    genders: "Optional[List[InlineResponse2006Genders]]" = Field(None, alias="genders")
    ttl: "Optional[float]" = Field(None, alias="ttl")


class InlineResponse2006Genders(BaseModel):
    gender: "str" = Field(..., alias="gender")
    gender_l: "Optional[str]" = Field(None, alias="gender_l")
    id: "float" = Field(..., alias="id")


class InlineResponse2007(BaseModel):
    beneficiary_reference_id: "Optional[str]" = Field(None, alias="beneficiary_reference_id")


class InlineResponse400(BaseModel):
    error_code: "Optional[str]" = Field(None, alias="errorCode")
    error: "Optional[str]" = Field(None, alias="error")


class SessionCalendarEntrySchema(BaseModel):
    center_id: "float" = Field(..., alias="center_id")
    name: "str" = Field(..., alias="name")
    name_l: "Optional[str]" = Field(None, alias="name_l")
    state_name: "str" = Field(..., alias="state_name")
    state_name_l: "Optional[str]" = Field(None, alias="state_name_l")
    district_name: "str" = Field(..., alias="district_name")
    district_name_l: "Optional[str]" = Field(None, alias="district_name_l")
    block_name: "str" = Field(..., alias="block_name")
    block_name_l: "Optional[str]" = Field(None, alias="block_name_l")
    pincode: "str" = Field(..., alias="pincode")
    lat: "Optional[float]" = Field(None, alias="lat")
    long: "Optional[float]" = Field(None, alias="long")
    _from: "str" = Field(..., alias="from")
    to: "str" = Field(..., alias="to")
    fee_type: "Literal['Free', 'Paid']" = Field(..., alias="fee_type")
    vaccine_fees: "Optional[List[VaccineFeeSchema]]" = Field(None, alias="vaccine_fees")
    sessions: "List[SessionCalendarEntrySchemaSessions]" = Field(..., alias="sessions")


class SessionCalendarEntrySchemaSessions(BaseModel):
    session_id: "UUID" = Field(..., alias="session_id")
    date: "str" = Field(..., alias="date")
    available_capacity: "float" = Field(..., alias="available_capacity")
    min_age_limit: "float" = Field(..., alias="min_age_limit")
    vaccine: "str" = Field(..., alias="vaccine")
    slots: "List[str]" = Field(..., alias="slots")


class SessionResponseSchema(BaseModel):
    center_id: "float" = Field(..., alias="center_id")
    name: "str" = Field(..., alias="name")
    name_l: "Optional[str]" = Field(None, alias="name_l")
    state_name: "str" = Field(..., alias="state_name")
    state_name_l: "Optional[str]" = Field(None, alias="state_name_l")
    district_name: "str" = Field(..., alias="district_name")
    district_name_l: "Optional[str]" = Field(None, alias="district_name_l")
    block_name: "str" = Field(..., alias="block_name")
    block_name_l: "Optional[str]" = Field(None, alias="block_name_l")
    pincode: "str" = Field(..., alias="pincode")
    lat: "Optional[float]" = Field(None, alias="lat")
    long: "Optional[float]" = Field(None, alias="long")
    _from: "str" = Field(..., alias="from")
    to: "str" = Field(..., alias="to")
    fee_type: "Literal['Free', 'Paid']" = Field(..., alias="fee_type")
    fee: "str" = Field(..., alias="fee")
    session_id: "UUID" = Field(..., alias="session_id")
    date: "str" = Field(..., alias="date")
    available_capacity: "float" = Field(..., alias="available_capacity")
    min_age_limit: "float" = Field(..., alias="min_age_limit")
    vaccine: "str" = Field(..., alias="vaccine")
    slots: "List[str]" = Field(..., alias="slots")


class SessionResponseSchemaAllOf(BaseModel):
    fee: "str" = Field(..., alias="fee")
    session_id: "UUID" = Field(..., alias="session_id")
    date: "str" = Field(..., alias="date")
    available_capacity: "float" = Field(..., alias="available_capacity")
    min_age_limit: "float" = Field(..., alias="min_age_limit")
    vaccine: "str" = Field(..., alias="vaccine")
    slots: "List[str]" = Field(..., alias="slots")


class VaccineFeeSchema(BaseModel):
    vaccine: "str" = Field(..., alias="vaccine")
    fee: "str" = Field(..., alias="fee")
